pub struct SimpleBufferPool { /* private fields */ }Implementations
Sourceimpl SimpleBufferPool
impl SimpleBufferPool
pub fn new() -> Self
Sourcepub fn outstanding_leases(&self) -> usize
pub fn outstanding_leases(&self) -> usize
Returns the number of buffers currently allocated and not yet released.
Sourcepub fn assert_no_leaks(&self)
pub fn assert_no_leaks(&self)
Panics (in debug builds and tests) if there are any unreleased buffers. Use at the end of a test to confirm there are no buffer leaks.